wk-20200101

The Workiva Platform 2024-07-30 iso4217:EUR 123456 2020-01-01 2020-03-31 123456 2020-03-31 123456 2019-01-01 2019-03-31
12
The Workiva Platform, Workiva bus:NameProductionSoftware
01/01/2020 EndDateForPeriodCoveredByReport
EntityCurrentLegalOrRegisteredName
01/01/2019 StartDateForPeriodCoveredByReport
12344 CompaniesRegistrationOfficeNumber
10 DPLGovernmentGrantIncome
5 DPLOtherOperatingIncome, i
10 DPLProfitLossBeforeTax,
11 DPLStaffCostsEmployeeBenefitsExpense,
1 DPLSubcontractorCosts,
3 DPLTurnoverRevenue.
5 Equity
1111 DPLGrossProfitLoss
EUR PrincipalCurrencyUsedInBusinessReport
USD PrincipalCurrencyUsedInBusinessReport
-1111 ProfitLossBeforeTax